utils.jsonapi — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# utils.jsonapi

## Module: `utils.jsonapi`

Priority based json library imports.

Use jsonapi.loads() and jsonapi.dumps() for guaranteed symmetry.

Priority: jsonlib2 > jsonlib > simplejson > json

Ensures bytes instead of unicode on either side of serialization.

### Authors

- MinRK
- Brian Granger

## Functions

`zmq.utils.jsonapi.` `dumps`(o, **kwargs)

`zmq.utils.jsonapi.` `jsonlib_dumps`(o, **kwargs)

  This one is separate because jsonlib doesn’t allow specifying separators. See jsonlib.dumps for details on kwargs.

`zmq.utils.jsonapi.` `loads`(s, **kwargs)

### Navigation

- index
- modules |
- previous |
- home|
- search|
- API »
- The PyZMQ API »